RPT_RF_ActiveSettings = nil;

function RPT_RF_InitConfig()
	
	
	RPT_RF_CharSettings = RPT_RF_CharSettings or {};
	
	-- set Defaults:
	if RPT_RF_CharSettings.version ~= 2 then
		RPT_RF_CharSettings.version = 2;
		RPT_RF_CharSettings.spec1 = RPT_RF_CharSettings.spec1 or {};
		RPT_RF_CharSettings.spec2 = RPT_RF_CharSettings.spec2 or {};
		
		-- cache the specs
		local spec1 = RPT_RF_CharSettings.spec1;
		local spec2 = RPT_RF_CharSettings.spec2;
		
		-- init the spec variables.
		spec1.hide = spec1.hide or false;
		spec2.hide = spec2.hide or false;
		
		spec1.layout = spec1.layout or 1;
		spec2.layout = spec2.layout or 1;
		
		spec1.hp_name = spec1.hp_name or 1;
		spec2.hp_name = spec2.hp_name or 1;
		
		spec1.hp_barC = spec1.hp_barC or 1;
		spec2.hp_barC = spec2.hp_barC or 1;
		
		spec1.scale = spec1.scale or 1;
		spec2.scale = spec2.scale or 1;
		
		spec1.capRaidGroups = spec1.capRaidGroups or false;
		spec2.capRaidGroups = spec2.capRaidGroups or false;
		
		-- Focus and Target frame.
		
		spec1.focusframe = spec1.focusframe or { };
		spec2.focusframe = spec2.focusframe or { };
		
		spec1.focusframe.active =  spec1.focusframe.active or false;
		spec2.focusframe.active =  spec2.focusframe.active or false;
		
		spec1.focusframe.scale =  spec1.focusframe.scale or 1;
		spec2.focusframe.scale =  spec2.focusframe.scale or 1;
		
		spec1.targetframe = spec1.targetframe or { };
		spec2.targetframe = spec2.targetframe or { };
		
		spec1.targetframe.active =  spec1.targetframe.active or false;
		spec2.targetframe.active =  spec2.targetframe.active or false;
		
		spec1.targetframe.scale =  spec1.targetframe.scale or 1;
		spec2.targetframe.scale =  spec2.targetframe.scale or 1;
		
		print("[RPT_RF]: Settings are changed or extra options are available.");
		print("[RPT_RF]: Type '/rpt' to check your options set for this spec.");
	end
	
	-- set active settings:
	RPT_RF_SetSettings();
end

function RPT_RF_ActivateSettings(spec)
	RPT_RF_ActiveSettings = spec;
	
	
	-- set the layout
	if spec.layout == 1 then RPT_RF_SetHealLayout()
	elseif spec.layout == 2 then RPT_RF_SetDpsLayout() end
	
	-- set scale
	
	if spec.scale == 0 then
		RPT_RF_Main:SetScale(0.01);
	else
		RPT_RF_Main:SetScale(spec.scale);
	end
	
	-- set hptext function
	RPT_RF_UpdateHealthText = _G["RPT_RF_UpdateHealthText"..spec.hp_name] or RPT_RF_UpdateHealthText1;
	
	-- set the barcolour
	for i=1, 40 do
		local frame = getglobal("RPT_RF_Player"..i);
		local info = RPT_RF_FrameInfo[i];
		
		if spec.hp_barC == 1 then	-- just green
			frame.hred = 0;
			frame.hblue = 0;
			frame.hgreen = 1;
		elseif spec.hp_barC == 2 then -- class color
			-- check class.
			local _, class2 = UnitClass(info.player);
			local color = RPT_ClassC[class2];
			if color then
				frame.hred   = color.r;
				frame.hblue  = color.b;
				frame.hgreen = color.g;
			end
		elseif spec.hp_barC == 3 then -- color shifting.
			frame.hblue  = 0;
		end
		
		if info.vehicle then
			RPT_RF_updateHealth(info.vUnit);
		else
			RPT_RF_updateHealth(info.player);
		end
		
		RPT_RF_SetBarColor(frame);
	end
	
	-- check or the focus frame must be hidden or not:
	RPT_RF_EF_ActivateFocusFrame(spec.focusframe.active);
	RPT_RF_EF_ActivateTargetFrame(spec.targetframe.active);
	
	
	-- check de scale.
	if spec.focusframe.scale == 0 then
		RPT_RF_FOCUSFRAME:SetScale(0.01);
	else
		RPT_RF_FOCUSFRAME:SetScale(0.5 * spec.focusframe.scale);
	end
	
	if spec.targetframe.scale == 0 then
		RPT_RF_TARGETFRAME:SetScale(0.01);
	else
		RPT_RF_TARGETFRAME:SetScale(0.5 * spec.targetframe.scale);
	end
	
	-- check or the interface must be hidden:
	RPT_RF_Toggle(not spec.hide);
	
	RPT_RF_OP_ShowSettings();
	
	-- sets the raid cap:
	RPT_RF_CheckInstance();
	
end

function RPT_RF_SetSettings()
-- set active settings:
	local talents = GetActiveTalentGroup(false,false);
	
	if talents == 1 then
		RPT_RF_ActivateSettings(RPT_RF_CharSettings.spec1);
	elseif talents == 2 then
		RPT_RF_ActivateSettings(RPT_RF_CharSettings.spec2);
	end
end

function RPT_RF_SaveSettings()
	-- save raidframes settings:
		RPT_RF_ActiveSettings.scale = RPT_OP4_SLD1:GetValue();
		RPT_RF_ActiveSettings.hide = not RPT_OP4_RB1_enable:GetChecked();
		RPT_RF_ActiveSettings.capRaidGroups = RPT_OP4_RB2_enable:GetChecked();
		RPT_RF_ActiveSettings.hp_name = UIDropDownMenu_GetSelectedID(RPT_OP4_DD1);
		RPT_RF_ActiveSettings.hp_barC = UIDropDownMenu_GetSelectedID(RPT_OP4_DD2);
	
	-- save focusframe settings:
		RPT_RF_ActiveSettings.focusframe.scale = RPT_OP3_SLD1:GetValue();
		RPT_RF_ActiveSettings.targetframe.scale = RPT_OP3_SLD2:GetValue();
		RPT_RF_ActiveSettings.focusframe.active = RPT_OP3_CBfocusframe:GetChecked();
		RPT_RF_ActiveSettings.targetframe.active = RPT_OP3_CBtargetframe:GetChecked();
		
	-- activate settings
	RPT_RF_ActivateSettings(RPT_RF_ActiveSettings);
end

function RPT_RF_OP_ShowSettings()
	-- raid panel
		local a = not RPT_RF_ActiveSettings.hide;
		RPT_OP4_RB1_enable:SetChecked(a);
		RPT_OP4_RB2_enable:SetChecked(RPT_RF_ActiveSettings.capRaidGroups);
		RPT_OP4_SLD1:SetValue(RPT_RF_ActiveSettings.scale);
		RPT_OPT_SetDropDownSelectedIDsafe( RPT_OP4_DD1, RPT_RF_ActiveSettings.hp_name);
		RPT_OPT_SetDropDownSelectedIDsafe( RPT_OP4_DD2, RPT_RF_ActiveSettings.hp_barC);
	
	-- focus panel
		RPT_OP3_CBfocusframe:SetChecked(RPT_RF_ActiveSettings.focusframe.active)
		RPT_OP3_CBtargetframe:SetChecked(RPT_RF_ActiveSettings.targetframe.active);
		RPT_OP3_SLD1:SetValue(RPT_RF_ActiveSettings.focusframe.scale);
		RPT_OP3_SLD2:SetValue(RPT_RF_ActiveSettings.targetframe.scale);
end